% This file simulates the standard BKK model with adjustment cost on quantities for 'Understanding International Prices: Customers and Capital'                                                  
% and computes business cycle statistics for the chosen parameters                                                                               
                                                                                                                                                 
% The user needs to supply the steady state associated with the given parameters, and the solution to the model                                  
% contained in the file Model.mat                                                                                                                
                                                                                                                                                 
% This code uses the routine dynare_simul, which is part of the dynare++ package, by Ondra Kamenik,                                              
% available at www.dynare.org                                                                                                                    
                                                                                                                                                 
% Authors: Lukasz A. Drozd and Jaromir B. Nosal, 2011                                                                                            



close all                                                                                                                                                                                                                                                                                                                       
clc                                                                                                                                                             
disp('THIS IS THE CONVEX FRICTION MODEL')                                                                                                                                                          
%Parameter values below                                                                                                                                         
                                                                                                                                                                
alf   =   0.36000000000000;                                                                                                                                                                  
sig   =   2.00000000000000;                                                                                                                                                                  
dk    =   0.02500000000000;                                                                                                                                                                  
gam   =   1.50000000000000;                                                                                                                                                                  
bet   =   0.99000000000000;                                                                                                                                                                  
eta   =   0.33540000000000;                                                                                                                                                                  
bias  =   0.79000000000000;                                                                                                                                                                  
rho11 =   0.91000000000000;                                                                                                                                                                  
rho22 =   0.91000000000000;                                                                                                                                                                  
rho21 =   0.00000000000000;                                                                                                                                                                  
rho12 =   0.00000000000000;                                                                                                                                                                  
lbar  =  10.00000000000000;                                                                                                                                                                  
tau   =   0.00000000000000;                                                                                                                                                                  
cost1d=  95.00000000000000;                                                                                                                                                                  
                                                                                                                                                                
%load file                                                                                                                                                      
load('-mat','modelCC.mat')                                                                                                                                        
                                                                                                                                                                
%set the two shocks                                                                                                                                             
SIGMA(1,1)=   0.00003700000000;                                                                                                                                                                  
SIGMA(2,2)=   0.00003700000000;                                                                                                                                                                  
SIGMA(2,1)=((SIGMA(1,1)*SIGMA(2,2))^(1/2))*   0.28000000000000;                                                                                                                                                                  
                                                                                                                                                                
SIGMA(1,2)=SIGMA(2,1);                                                                                                                                          
MU  =[0;0];                                                                                                                                                     
inv1=[];                                                                                                                                                        
inv2=[];                                                                                                                                                        
randn('state',0);                                                                                                                                               
shocks=mvnrnd(MU,SIGMA,15000)';                                                                                                                                 
shocks(:,1:150)=0.0 ;                                                                                                                                           
shocks(1,6)   =0.01;                                                                                                                                            
r = dynare_simul('modelCC.mat',shocks, dyn_ss);                                                                                                                   
                                                                                                                                                                
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                                          
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              
%prices                                                                                                                                                         
p1d=r(dyn_i_p1d(1),:);                                                                                                                                          
p2d=r(dyn_i_p2d(1),:);                                                                                                                                          
p1f=r(dyn_i_p1f(1),:);                                                                                                                                          
p2f=r(dyn_i_p2f(1),:);                                                                                                                                          
d1=r(dyn_i_d1(1),:);                                                                                                                                            
d2=r(dyn_i_d2(1),:);                                                                                                                                            
f1=r(dyn_i_f1(1),:);                                                                                                                                            
f2=r(dyn_i_f2(1),:);                                                                                                                                            
r1=r(dyn_i_r1(1),:);                                                                                                                                            
r2=r(dyn_i_r2(1),:);                                                                                                                                            
w1=r(dyn_i_w1(1),:);                                                                                                                                            
w2=r(dyn_i_w2(1),:);                                                                                                                                            
z1=r(dyn_i_z1(1),:);                                                                                                                                            
z2=r(dyn_i_z2(1),:);                                                                                                                                            
v1 =  1.0./(z1*(1-alf)).*w1.^(1-alf).*r1.^alf * ((1-alf)/alf)^alf ;                                                                                             
v2 =  1.0./(z2*(1-alf)).*w2.^(1-alf).*r2.^alf * ((1-alf)/alf)^alf ;                                                                                             
c1=r(dyn_i_c1(1),:);                                                                                                                                            
c2=r(dyn_i_c2(1),:);         
l1=r(dyn_i_l1(1),:);                                                                                                                                            
l2=r(dyn_i_l2(1),:);         
ccs=c1./c2;       
kernel=(eta*(c2.^eta.*(lbar-l2).^(1-eta)).^(1-sig)./c2)./(eta*(c1.^eta.*(lbar-l1).^(1-eta)).^(1-sig)./c1);
x=r(dyn_i_x(1),:);                                                                                                                                              
ratio1=r(dyn_i_ratio1(1),:);                                                                                                                                    
ratio2=r(dyn_i_ratio2(1),:);                                                                                                                                    
                                                                                                                                                                
%gdp                                                                                                                                                            
rGDP1  = p1d(1)*r(dyn_i_d1(1),:)+ (p1f(1)*(1+tau))*r(dyn_i_f1(1),:) - p1f(1)*r(dyn_i_f1(1),:) + p2d(1)*r(dyn_i_d2(1),:);                                        
rGDP2  = p2f(1)*r(dyn_i_f2(1),:)+ (p2d(1)*(1+tau))*r(dyn_i_d2(1),:) - p2d(1)*r(dyn_i_d2(1),:) + p1f(1)*r(dyn_i_f1(1),:);                                        
nGDP1  = p1d.*r(dyn_i_d1(1),:)+ ((1+tau)*p1f).*r(dyn_i_f1(1),:) - p1f.*r(dyn_i_f1(1),:) + r(dyn_i_x(1),:).*p2d.*r(dyn_i_d2(1),:);                               
nGDP2  = p2f.*r(dyn_i_f2(1),:)+ ((1+tau)*p2d).*r(dyn_i_d2(1),:) - p2d.*r(dyn_i_d2(1),:) + p1f.*r(dyn_i_f1(1),:)./r(dyn_i_x(1),:);                               
%kernel  = (r(dyn_i_c1(1),2:5000)./r(dyn_i_c1(1),1:4999)).^(-gam);                                                                                               
                                                                                                                                                                
TFP1(2:15000)= log(rGDP1(2:15000))-alf*log(r(dyn_i_k1(1),1:14999))-(1-alf)*log(r(dyn_i_l1(1),2:15000));                                                         
TFP2(2:15000)= log(rGDP2(2:15000))-alf*log(r(dyn_i_k2(1),1:14999))-(1-alf)*log(r(dyn_i_l2(1),2:15000));                                                         
TFP1(1)     = TFP1(2);                                                                                                                                          
TFP2(1)     = TFP2(2);                                                                                                                                          
%prices                                                                                                                                                         
Pd1=p1d;                                                                                                                                                        
Pd2=p2d*(1+tau);                                                                                                                                                
Pf1=p1f*(1+tau);                                                                                                                                                
Pf2=p2f;                                                                                                                                                        
Omg    = 1-r(dyn_i_f1(1),1)*p1f(1)/rGDP1(1);                                                                                                                    
G1d    = bias*d1.^(-1/gam).*(bias*d1.^((gam-1)/gam)+(1-bias)*f1.^((gam-1)/gam)).^(1/(gam-1));                                                                   
G1f    = (1-bias)*f1.^(-1/gam).*(bias*d1.^((gam-1)/gam)+(1-bias)*f1.^((gam-1)/gam)).^(1/(gam-1));                                                               
G2f    = bias*f2.^(-1/gam).*(bias*f2.^((gam-1)/gam)+(1-bias)*d2.^((gam-1)/gam)).^(1/(gam-1));                                                                   
G2d    = (1-bias)*d2.^(-1/gam).*(bias*f2.^((gam-1)/gam)+(1-bias)*d2.^((gam-1)/gam)).^(1/(gam-1));                                                               
CPI1   = (bias^gam*G1d.^(1-gam)+(1-bias)^gam*G1f.^(1-gam)).^(1/(1-gam));                                                                                        
CPI2   = (bias^gam*G2f.^(1-gam)+(1-bias)^gam*G2d.^(1-gam)).^(1/(1-gam));                                                                                        
CPI2PT = (Omg*p1f./x+(1-Omg)*p2d);                                                                                                                              
CPI1PT = (Omg*p1f.*x+(1-Omg)*p2d);                                                                                                                              
xTcpi  = x.*CPI2./CPI1;                                                                                                                                         
xPT    = (x.*CPI2PT)./CPI1PT;                                                                                                                                   
%deflators                                                                                                                                                      
defGDP1 = nGDP1./rGDP1;                                                                                                                                         
defGDP2 = nGDP2./rGDP2;                                                                                                                                         
epi     = r(dyn_i_x(1),:).*p2d./defGDP1;                                                                                                                        
ipi     = p1f./defGDP1;                                                                                                                                         
epi_cpi = r(dyn_i_x(1),:).*p2d;                                                                                                                                 
ipi_cpi = p1f;                                                                                                                                                  
                                                                                                                                                                
LOOP   = (x.*p2d)./p1d;                                                                                                                                         
%trade prices                                                                                                                                                   
Px     = x.*p2d;%./CPI1;                                                                                                                                        
Pm     = p1f;%./CPI1;                                                                                                                                           
P      = Pm./Px;                                                                                                                                                
                                                                                                                                                                
%domestic absorption                                                                                                                                            
rDA =rGDP1-p2d(1)*r(dyn_i_d2(1),:);                                                                                                                             
nDA =nGDP1-x.*p2d.*r(dyn_i_d2(1),:);                                                                                                                            
PDA=nDA./rDA;                                                                                                                                                   
                                                                                                                                                                
%Armington elasticity                                                                                                                                           
RATdf   = rDA./r(dyn_i_f1(1),:); %r(dyn_i_d1(1),:);                                                                                                             
RATpfpd = p1f./PDA;                                                                                                                                             
%tot and CA                                                                                                                                                     
rer     = r(dyn_i_x(1),:);                                                                                                                                      
                                                                                                                                                                
                                                                                                                                                                
tot     = Pm./Px;                                                                                                                                               
CA      = exp( ( r(dyn_i_x(1),:).*p2d.*r(dyn_i_d2(1),:)-p1f.*r(dyn_i_f1(1),:) )./nGDP1 );                                                                       
rCA     = exp( ( p2d(1)*r(dyn_i_d2(1),:)-p1f(1)*r(dyn_i_f1(1),:) )./rGDP1 );                                                                                    
                                                                                                                                                                
neg=0;                                                                                                                                                          
                                                                                                                                                                
                                                                                                                                                                
dyn_i_rGDP1(1)=size(r,1)+1;                                                                                                                                     
dyn_i_rGDP2(1)=size(r,1)+2;                                                                                                                                     
dyn_i_epi(1)  =size(r,1)+3;                                                                                                                                     
dyn_i_ipi(1)  =size(r,1)+4;                                                                                                                                     
dyn_i_tot(1)  =size(r,1)+5;                                                                                                                                     
dyn_i_rer(1)  =size(r,1)+6;                                                                                                                                     
dyn_i_CA(1)   =size(r,1)+7;                                                                                                                                     
dyn_i_Px(1)     = size(r,1)+8;                                                                                                                                  
dyn_i_Pm(1)     = size(r,1)+9;                                                                                                                                  
dyn_i_P(1)      = size(r,1)+10;                                                                                                                                 
dyn_i_TFP1(1)   = size(r,1)+11;                                                                                                                                 
dyn_i_TFP2(1)   = size(r,1)+12;                                                                                                                                 
dyn_i_RATdf(1)  = size(r,1)+13;                                                                                                                                 
dyn_i_RATpfpd(1)= size(r,1)+14;                                                                                                                                 
dyn_i_xTcpi(1)  = size(r,1)+15;                                                                                                                                 
dyn_i_xPT(1)    = size(r,1)+16;                                                                                                                                 
dyn_i_LOOP(1)   = size(r,1)+17;                                                                                                                                 
dyn_i_ccs(1)   = size(r,1)+18;    
dyn_i_kernel(1)   = size(r,1)+19;     
                                                                                                                                                                
for index=1:14999                                                                                                                                               
inv1(index)    =r(dyn_i_k1(1),index+1)-(1-dk)*r(dyn_i_k1(1),index);                                                                                             
inv2(index)    =r(dyn_i_k2(1),index+1)-(1-dk)*r(dyn_i_k2(1),index);                                                                                             
                                                                                                                                                                
    if inv1(index)<=0 || inv2(index)<=0                                                                                                                         
         neg=1;                                                                                                                                                 
     end                                                                                                                                                        
 end                                                                                                                                                            
                                                                                                                                                                
inv1(15000)=inv1(14999);                                                                                                                                        
inv2(15000)=inv2(14999);                                                                                                                                        
                                                                                                                                                                
TS=[r(:,50:15000);rGDP1(50:15000);rGDP2(50:15000);epi(50:15000);ipi(50:15000); ...                                                                              
tot(50:15000);rer(50:15000);CA(50:15000); Px(50:15000);Pm(50:15000); P(50:15000); exp(TFP1(50:15000));exp(TFP2(50:15000)); ...                                  
 RATdf(50:15000);RATpfpd(50:15000); xTcpi(50:15000); xPT(50:15000); LOOP(50:15000);ccs(50:15000);kernel(50:15000)];                                                              
                                                                                                                                                                
TS=log(TS');                                                                                                                                                    
dTS=TS - hpfilter(TS,1600);                                                                                                                                      
regA=[RATdf;RATpfpd];                                                                                                                                           
regA=log(regA');                                                                                                                                                
dregA=regA-hpfilter(regA,1600);                                                                                                                                  
markups=[];                                                                                                                                                     
ppd=[];                                                                                                                                                         
ppd(1,:)=p1d;                                                                                                                                                   
ppd(2,:)=p2d;                                                                                                                                                   
ppf=[];                                                                                                                                                         
ppf(1,:)=p1f;                                                                                                                                                   
ppf(2,:)=p2f;                                                                                                                                                   
                                                                                                                                                                
                                                                                                                                                                
if neg==0                                                                                                                                                       
    inv=log([inv1(50:15000);inv2(50:15000)]');                                                                                                                  
    dinv=inv - hpfilter(inv,1600);                                                                                                                               
end                                                                                                                                                             
                                                                                                                                                                
rCA=log(rCA(50:15000)');                                                                                                                                        
[rCA_t,rCA_d]=hpfilter(rCA,1600);                                                                                                                                
sd=100*std(dTS);                                                                                                                                                
if neg==0                                                                                                                                                       
    sdinv=100*std(dinv);                                                                                                                                        
end                                                                                                                                                             
warning off MATLAB:divideByZero                                                                                                                                 
                                                                                                                                                                
cc= corrcoef(dTS);                                                                                                                                              
                                                                                                                                                                
if neg==0                                                                                                                                                       
ccinv= corrcoef(dinv);                                                                                                                                          
end                                                                                                                                                             
                                                                                                                                                                
if neg==0                                                                                                                                                       
ccyi=corrcoef(dinv(:,1),dTS(:,dyn_i_rGDP1(1)));                                                                                                                 
end                                                                                                                                                             
                                                                                                                                                                
coefreg0=regress(dregA(100:14900,1),[ones(14801,1) dregA(100:14900,2)]);                                                                                        
coefreg1=regress(dTS(100:14000,dyn_i_Pm(1)),[ones(13901,1) dTS(100:14000,dyn_i_xTcpi(1))]);                                                                     
coefreg2=regress(regA(100:14900,1),[ones(14801,1) regA(100:14900,2)]);                                                                                          
coefreg3=regress(dTS(100:14000,dyn_i_Px(1)),[ones(13901,1) dTS(100:14000,dyn_i_xTcpi(1))]);                                                                     
corPxX=corrcoef(dTS(100:14000,dyn_i_Px(1)),dTS(100-1:14000-1,dyn_i_xTcpi(1)));                                                                                  
[B1,BINT1,R1,RINT1,STATS1]=regress(exp(TFP1(51:14001))',[ones(1,13951);exp(TFP1(50:14000))]');                                                                  
[B3,BINT3,R3,RINT3,STATS3]=regress((LOOP(51:14001))',[ones(1,13951);(LOOP(50:14000))]');                                                                        
[B2,BINT2,R2,RINT2,STATS2]=regress(r(dyn_i_z1(1),51:12001)',[ones(1,11951);r(dyn_i_z1(1),50:12000)]');                                                          
disp('========================================')                                                                                                                
disp('PARAMETERS')                                                                                                                                              
fprintf('Discount factor            (beta)= %g\n',bet)                                                                                                          
fprintf('Labor income in GDP        (alfa)= %g\n',alf)                                                                                                          
fprintf('Intertemporal substitution(sigma)= %g\n',sig)                                                                                                          
fprintf('Consumption/leisure         (eta)= %g\n',eta)                                                                                                          
fprintf('Armington aggreg. elast.  (gamma)= %g\n',gam)                                                                                                          
fprintf('Depreciation of capital      (dk)= %g\n',dk)                                                                                                           
fprintf('Home bias parameter  (omega/bias)= %g\n',bias)                                                                                                         
fprintf('Trasportation cost          (tau)= %g\n',tau)                                                                                                          
fprintf('Adjustment friction         (phi)= %g\n',cost1d)                                                                                                       
disp('========================================')                                                                                                                
disp('BUSINESS CYCLE VOLATILITY (IN PERCENT)')                                                                                                                  
fprintf('s.d.(TFP1 assumed) = %.4f\n',sd(dyn_i_z1(1)))                                                                                                          
fprintf('s.d.(TFP2 assumed) = %.4f\n',sd(dyn_i_z2(1)))                                                                                                          
fprintf('s.d.(TFP1 actual)  = %.4f\n',sd(dyn_i_TFP1(1)))                                                                                                        
fprintf('s.d.(TFP2 actual)  = %.4f\n',sd(dyn_i_TFP2(1)))                                                                                                        
fprintf('s.d.(OUTPUT)       = %.4f\n',sd(dyn_i_rGDP1(1)))                                                                                                       
fprintf('s.d.(CONSUMPTION)  = %.4f\n',sd(dyn_i_c1(1)))                                                                                                          
fprintf('s.d.(LABOR)        = %.4f\n',sd(dyn_i_l1(1)))                                                                                                          
fprintf('s.d.(CA)           = %.4f\n',sd(dyn_i_CA(1)))                                                                                                          
fprintf('s.d.(TOT)          = %.4f\n',sd(dyn_i_P(1)))                                                                                                           
fprintf('s.d.(RER_T_CPI)    = %.4f\n',sd(dyn_i_xTcpi(1)))                                                                                                       
fprintf('s.d.(RER_PT)       = %.4f\n',sd(dyn_i_xPT(1)))                                                                                                         
fprintf('s.d.(Px)           = %.4f\n',sd(dyn_i_Px(1)))                                                                                                          
fprintf('s.d.(Pm)           = %.4f\n',sd(dyn_i_Pm(1)))                                                                                                          
fprintf('s.d.(W)            = %.4f\n',sd(dyn_i_w1(1)))                                                                                                          
fprintf('s.d.(INVESTMENT)  = %.2f\n',sdinv(1))                                                                                                                  
disp('=========================================')                                                                                                               
disp('INTERNATIONAL CORRELATIONS')                                                                                                                              
fprintf('corr(TFP assumed) = %.4f\n',cc(dyn_i_z1(1),dyn_i_z2(1)))                                                                                               
fprintf('corr(TFP actual)  = %.4f\n',cc(dyn_i_TFP1(1),dyn_i_TFP2(1)))                                                                                           
fprintf('corr(OUTPUT)      = %.4f\n',cc(dyn_i_rGDP1(1),dyn_i_rGDP2(1)))                                                                                         
fprintf('corr(CONSUMPTION) = %.4f\n',cc(dyn_i_c1(1),dyn_i_c2(1)))                                                                                               
fprintf('corr(LABOR)       = %.4f\n',cc(dyn_i_l1(1),dyn_i_l2(1)))                                                                                               
fprintf('corr(Px,Pm)       = %.4f\n',cc(dyn_i_Px(1),dyn_i_Pm(1)))                                                                                               
fprintf('corr(Px,RER)      = %.4f\n',cc(dyn_i_Px(1),dyn_i_xTcpi(1)))                                                                                            
fprintf('corr(Pm,RER)      = %.4f\n',cc(dyn_i_Pm(1),dyn_i_xTcpi(1)))                                                                                            
dxTcpi=log(xTcpi(50:15000)')-hpfilter(log(xTcpi(50:15000)'),1600);                                                                                               
correlPxRer1=corrcoef(dTS(2:14000,dyn_i_Px(1)), dxTcpi(1:13999));                                                                                               
fprintf('corr(Px,RER(-1))  = %.2f\n',correlPxRer1(2,1))                                                                                                         
fprintf('corr(TOT,RER)     = %.4f\n',cc(dyn_i_P(1), dyn_i_xTcpi(1)))                                                                                            
fprintf('corr(INVESTMENT)  = %.2f\n',ccinv(1,2))                                                                                                                
                                                                                                                                                                
disp('=========================================')                                                                                                               
disp('BUSINESS CYCLE CORRELATIONS')                                                                                                                             
fprintf('corr(OUTPUT,CONS.)= %.4f\n',cc(dyn_i_rGDP1(1),dyn_i_c1(1)))                                                                                            
fprintf('corr(OUTPUT,LABOR)= %.4f\n',cc(dyn_i_rGDP1(1),dyn_i_l1(1)))                                                                                            
fprintf('corr(OUTPUT,CA)   = %.4f\n',cc(dyn_i_rGDP1(1),dyn_i_CA(1)))                                                                                            
fprintf('corr(TOT,CA)      = %.4f\n',cc(dyn_i_P(1),    dyn_i_CA(1)))                                                                                            
fprintf('corr(TOT,RER)     = %.4f\n',cc(dyn_i_P(1),    dyn_i_xTcpi(1)))                                                                                         
fprintf('corr(TOT,GDP)     = %3.7f\n',cc(dyn_i_P(1),    dyn_i_rGDP1(1)))                                                                                        
fprintf('corr(OUTPUT,INV.) = %.2f\n',ccyi(1,2))                                                                                                                 
                                                                                                                                                                
disp('=========================================')                                                                                                               
disp('CA has been divided by nom. GDP and then HP filtered.  ')                                                                                                 
disp('   ')                                                                                                                                                     
disp('CONSTRUCTED STATISTICS')                                                                                                                                  
fprintf('1. Imports/GDP      = %3.4f%%\n', (100*(1-Omg)))                                                                                                       
fprintf('2. sd(f/d)/sd(x)       = %3.4f%%\n', 10000*std(dregA(50:15000,1))/sd(dyn_i_x(1)))                                                                      
fprintf('3. rho of actual TFP   = %3.4f%%\n', B1(2))                                                                                                            
fprintf('4. rho of assumed TFP  = %3.4f%%\n', B2(2))                                                                                                            
fprintf('5. work time           = %3.4f%%\n', 100*r(dyn_i_l1(1),1)/lbar)                                                                                        
fprintf('6. sd(f/d)/sd(Pd/pf) (Volatility Ratio)   = %.1f%%\n', 100*std(dregA(50:15000,1))/std(dregA(50:15000,2)))                                              
fprintf('7. sd(f/d)/sd(RER)                        = %.2f%%\n', (10000*std(dregA(50:15000,1))/sd(dyn_i_xTcpi(1))))                                              
fprintf('8. sd(px)/sd(RER)                         = %.2f%%\n', (100*sd(dyn_i_Px(1))/sd(dyn_i_xTcpi(1))))                                                       
fprintf('9. sd(pm)/sd(RER)                         = %.2f%%\n', (100*sd(dyn_i_Pm(1))/sd(dyn_i_xTcpi(1))))                                                       
fprintf('10. sd(pd)/sd(RER)                        = %.2f%%\n', (100*sd(dyn_i_p1d(1))/sd(dyn_i_xTcpi(1))))                                                      
fprintf('11. sd(TOT)/sd(RER)                       = %.2f%%\n', (100*sd(dyn_i_P(1))/sd(dyn_i_xTcpi(1))))                                                        
fprintf('12. sd(px/pd)/sd(RER)                     = %.2f%%\n', (100*sd(dyn_i_LOOP(1))/sd(dyn_i_xTcpi(1))))                                                     
fprintf('13. Corr(c/c*, RER)                       = %.2f\n', cc(dyn_i_ccs(1),dyn_i_xTcpi(1)))                                                                  
fprintf('14. sd(consumption)/sd(GDP)               = %.2f%%\n', (100*sd(dyn_i_c1(1))/sd(dyn_i_rGDP1(1))))                                                       
fprintf('15. sd(investment)/sd(GDP)                = %.2f%%\n', (100*sdinv(1)/sd(dyn_i_rGDP1(1))))                                                              
fprintf('16. sd(employment)/sd(GDP)                = %.2f%%\n', (100*sd(dyn_i_l1(1))/sd(dyn_i_rGDP1(1))))                                                       
fprintf('17. sd(Net exports)/sd(GDP)               = %.2f%%\n', (100*sd(dyn_i_CA(1))/sd(dyn_i_rGDP1(1))))                                                       
disp('========================================= Execution complete')                                                                                                                                                                                                                                                                                                  
                                                                                                                                                                
if neg==0                                                                                                                                                       
ccyi=corrcoef(dinv(:,1),dTS(:,dyn_i_rGDP1(1)));                                                                                                                 
else                                                                                                                                                            
ccyi(1:2,1:2)=0;                                                                                                                                                
fprintf('investment is negative \n')                                                                                                                            
end                                                                                                                                                             
                                                                                                                                                                
                                                                                                                                                                
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                                                
                                                                                                                                                                
                                                                                                                                                                
T=40;                                                                                                                                                           
figure(1);                                                                                                                                                      
subplot(2,2,1)                                                                                                                                                  
plot([0:T],100*r(dyn_i_z1(1),1:T+1)/r(dyn_i_z1(1),1)-100,'--k',[0:T],100*r(dyn_i_z2(1),1:T+1)/r(dyn_i_z2(1),1)-100,'b','LineWidth',2)                           
ylabel('Percent deviation','FontSize',9)                                                                                                                        
xlabel('Quarters after shock','FontSize',9)                                                                                                                     
legend('z1','z2')                                                                                                                                               
grid on                                                                                                                                                         
                                                                                                                                                                
subplot(2,2,2)                                                                                                                                                  
plot([0:T],f1(1:T+1)./(d1(1:T+1)+f1(1:T+1)),'--k',[0:T],d2(1:T+1)./(d2(1:T+1)+f2(1:T+1)),'b','LineWidth',2)                                                     
ylabel('Percent deviation','FontSize',9)                                                                                                                        
xlabel('Quarters after shock','FontSize',9)                                                                                                                     
legend('f1/(f1+d1)', 'd2/(f2+d2)')                                                                                                                              
grid on                                                                                                                                                         
                                                                                                                                                                
subplot(2,2,3)                                                                                                                                                  
plot([0:T],100*x(1:T+1)/x(1)-100,'--k',[0:T],100*Px(1:T+1)/Px(1)-100,...                                                                                        
[0:T],100*Pm(1:T+1)/Pm(1)-100,[0:T],100*p1d(1:T+1)/p1d(1)-100,'LineWidth',2)                                                                                    
ylabel('Percent deviation','FontSize',9)                                                                                                                        
xlabel('Quarters after shock','FontSize',9)                                                                                                                     
legend('x', 'p_x', 'p_m', 'p_d' )                                                                                                                               
grid on                                                                                                                                                         
                                                                                                                                                                
subplot(2,2,4)                                                                                                                                                  
plot([0:T],100*Pd1(1:T+1)/Pd1(1)-100,'--k',[0:T],100*x(1:T+1).*Pd2(1:T+1)/(x(1)*Pd2(1))-100,'b','LineWidth',2)                                                  
ylabel('Percent deviation','FontSize',9)                                                                                                                        
xlabel('Quarters after shock','FontSize',9)                                                                                                                     
legend('Pd1', 'xPd2')                                                                                                                                           
grid on                                                                                                                                                         
