% This file simulates the model for 'Understanding International Prices: Customers and Capital'                                                  
% and computes business cycle statistics for the Static Friction case                                                                            
% Here, we are shutting down the labor/leisure choice and capital by appropriate setting of alpha and dk                                         
% The user needs to supply the steady state associated with the given parameters, and the solution to the model                                  
% contained in the file Model.mat                                                                                                                
                                                                                                                                                 
% This code uses the routine dynare_simul, which is part of the dynare++ package, by Ondra Kamenik,                                              
% available at www.dynare.org                                                                                                                    
                                                                                                                                                 
% Authors: Lukasz A. Drozd and Jaromir B. Nosal, 2011                                                                                            
                                                                                                                                                 
                                                                                                                                                 
close all                                                                                                                                                  
clear                                                                                                                                            
clc                                                                                                                                              

disp('STATIC FRICTION CASE')

%Parameter values                                                                                                                                
alf   =   0.00000010000000;                                                                                                                                                              
chi   =   0.95338000000000;                                                                                                                                                              
sig   =   2.00000000000000;                                                                                                                                                              
dk    =   0.99999900000000;                                                                                                                                                              
dh    =   0.09584845497074;                                                                                                                                                              
gam   =   7.90000000000000;                                                                                                                                                              
bet   =   0.99000000000000;                                                                                                                                                              
tet   =   0.50000000000000;                                                                                                                                                              
ome1  =   0.56246285335930;                                                                                                                                                              
ome2  =   0.43753714664070;                                                                                                                                                              
phi   =   0.91500000000000;                                                                                                                                                              
rho11 =   0.82000000000000;                                                                                                                                                              
rho22 =   0.82000000000000;                                                                                                                                                              
eta   =   0.99990143652530;                                                                                                                                                              
lbar  =   1.00000000000000;                                                                                                                                                              
tau   =   0.00000000000000;                                                                                                                                                              
rho   =   1.00000000000000;                                                                                                                                                              
psiT   =   0.00000000000000;                                                                                                                                                              
                                                                                                                                                 
%load file                                                                                                                                       
load('-mat','ModelStatic.mat')                                                                                                                         
                                                                                                                                                 
%set the two shocks                                                                                                                              
SIGMA(1,1)=   0.00006900000000;                                                                                                                                                              
SIGMA(2,2)=   0.00006900000000;                                                                                                                                                              
SIGMA(2,1)=((SIGMA(1,1)*SIGMA(2,2))^(1/2))*   0.28000000000000; 
%shocks are symmetric                                                                                                                            
SIGMA(1,2)=SIGMA(2,1);                                                                                                                           
%Generate random numbers                                                                                                                         
MU  =[0;0];                                                                                                                                      
inv1=[];                                                                                                                                         
inv2=[];                                                                                                                                         
randn('state',1);                                                                                                                                
shocks=mvnrnd(MU,SIGMA,15000)';                                                                                                                  
shocks(:,1:50)=0.0 ;                                                                                                                             
shocks(1,6)   =0.01;                                                                                                                             
%shocks(:,:)=0;                                                                                                                                  
r = [];                                                                                                                                          
%Simulate the model                                                                                                                              
r = dynare_simul('ModelStatic.mat',shocks, dyn_ss);                                                                                                    
                                                                                                                                                 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                           
                                                                                                                                                 
                                                                                                                                                 
h1=r(dyn_i_h1(1),:);                                                                                                                             
h2=r(dyn_i_h2(1),:);                                                                                                                             
TME=h1./h2;                                                                                                                                      
d1=r(dyn_i_d1(1),:);                                                                                                                             
f1=r(dyn_i_f1(1),:);                                                                                                                             
d2=r(dyn_i_d2(1),:);                                                                                                                             
f2=r(dyn_i_f2(1),:);                                                                                                                             
m1bar=r(dyn_i_m1d(1),:)+r(dyn_i_m1f(1),:);                                                                                                       
m2bar=r(dyn_i_m2d(1),:)+r(dyn_i_m2f(1),:);                                                                                                       
z1=r(dyn_i_z1(1),:);                                                                                                                             
z2=r(dyn_i_z2(1),:);                                                                                                                             
                                                                                                                                                 
%prices                                                                                                                                          
a2d=r(dyn_i_a2d(1),:);                                                                                                                           
a1f=r(dyn_i_a1f(1),:);                                                                                                                           
a1d=r(dyn_i_a1d(1),:);                                                                                                                           
a2f=r(dyn_i_a2f(1),:);                                                                                                                           
m2d=r(dyn_i_m2d(1),:);                                                                                                                           
m1f=r(dyn_i_m1f(1),:);                                                                                                                           
m1d=r(dyn_i_m1d(1),:);                                                                                                                           
m2f=r(dyn_i_m2f(1),:);                                                                                                                           
Pd1=r(dyn_i_P1d(1),:);                                                                                                                           
Pd2=r(dyn_i_P2d(1),:);                                                                                                                           
Pf1=r(dyn_i_P1f(1),:);                                                                                                                           
Pf2=r(dyn_i_P2f(1),:);                                                                                                                           
v1=r(dyn_i_vd(1),:);                                                                                                                             
v2=r(dyn_i_vf(1),:);                                                                                                                             
l1=r(dyn_i_l1(1),:);                                                                                                                             
l2=r(dyn_i_l2(1),:);                                                                                                                             
                                                                                                                                                           
c1=r(dyn_i_c1(1),:);                                                                                                                                       
c2=r(dyn_i_c2(1),:);                                                                                                                                       
ccs=c1./c2;                                                                                                                                                
                                                                                                                                                           
x  =r(dyn_i_x(1),:);                                                                                                                             
p1d=tet*(r(dyn_i_P1d(1),:)-psiT*r(dyn_i_vd(1),:))+(1-tet)*r(dyn_i_vd(1),:);                                                                      
p2d=tet*rho*(r(dyn_i_P2d(1),:)/(1+tau)-psiT*r(dyn_i_vf(1),:))+(1-tet)*r(dyn_i_vd(1),:)./r(dyn_i_x(1),:);                                         
p1f=tet*rho*(r(dyn_i_P1f(1),:)/(1+tau)-psiT*r(dyn_i_vd(1),:))+(1-tet)*r(dyn_i_vf(1),:).*r(dyn_i_x(1),:);                                         
p2f=tet*(r(dyn_i_P2f(1),:)-psiT*r(dyn_i_vd(1),:))+(1-tet)*r(dyn_i_vf(1),:);                                                                      
xPPI=((p1f.*f1+x.*p2f.*f2)./(f1+f2))./( (p1d.*d1+x.*p2d.*d2)./(d1+d2) );                                                                         
xhat=((Pf1.*f2+Pd1.*d2)./(f2+d2))./( (Pd1.*d1+Pf1.*f1)./(d1+f1) );                                                                               
px  =x.*p2d;                                                                                                                                     
pm  =p1f;                                                                                                                                        
MTf=(r(dyn_i_m2d(1),:)+r(dyn_i_m2f(1),:))./r(dyn_i_h2(1),:);                                                                                     
MTd=(r(dyn_i_m1d(1),:)+r(dyn_i_m1f(1),:))./r(dyn_i_h1(1),:);                                                                                     
CE =(r(dyn_i_m2d(1),:)+r(dyn_i_m2f(1),:))./(r(dyn_i_m1d(1),:)+r(dyn_i_m1f(1),:));                                                                
MFTf =((px-v1)./MTf)./(x.*v2);                                                                                                                   
MFTd =((p1d-v1)./MTd)./v1;                                                                                                                       
lb2d =px-v1;                                                                                                                                     
lb1d =p1d-v1;                                                                                                                                    
lb1f=pm-x.*v2;                                                                                                                                   
lb2f=x.*p2f-x.*v2;                                                                                                                               
RMUP  =(x.*p2d-v1)./(p1d-v1);                                                                                                                    
RPC   =(x.*v2)./v1;                                                                                                                              
PMR   = (f1./d1)/(f1(1)/d1(1));                                                                                                                  
xalt  = (Pd1.*(d2./(d2+f2))+Pf1.*(f2./(d2+f2)));                                                                                                 
                                                                                                                                                 
%GDP and actual TFP                                                                                                                              
rGDP1           = Pd1(1)*d1+ Pf1(1)*f1+(x(1)*p2d(1)*(1+tau)*d2+v1(1)*a1f-p1f(1)*f1-x(1)*v2(1)*a2d);                                              
rGDP2           = Pf2(1)*f2+ Pd2(1)*d2+(p1f(1)*(1+tau)*f1/x(1)+v2(1)*a2d-p2d(1)*d2-v1(1)/x(1)*a1f);                                              
r(dyn_i_c1(1),:)= (Pd1(1)*d1+Pf1(1)*f1).*(r(dyn_i_c1(1),:)./r(dyn_i_G1(1),:));                                                                   
r(dyn_i_c2(1),:)= (Pd2(1)*d2+Pf2(1)*f2).*(r(dyn_i_c2(1),:)./r(dyn_i_G2(1),:));                                                                   
nGDP1           = Pd1.*d1+ Pf1.*f1+x.*p2d.*d2*(1+tau)+v1.*a1f-p1f.*f1-x.*v2.*a2d;                                                                
TFP1(2:15000)   = log(rGDP1(2:15000))-alf*log(r(dyn_i_k1(1),1:14999))-(1-alf)*log(r(dyn_i_l1(1),2:15000));                                       
TFP2(2:15000)   = log(rGDP2(2:15000))-alf*log(r(dyn_i_k2(1),1:14999))-(1-alf)*log(r(dyn_i_l2(1),2:15000));                                       
TFP1(1)         = TFP1(2);                                                                                                                       
TFP2(1)         = TFP2(2);                                                                                                                       
Omg             = 1.0-(p1f(1)*f1(1)+v1(1)*a1f(1))/rGDP1(1);                                                                                      
                                                                                                                                                 
for i=1:150;                                                                                                                                     
dTFP1=(TFP1((i-1)*100+1:i*100)')-hpfilter((TFP1((i-1)*100+1:i*100)'),100000000);                                                                  
dTFP2=(TFP2((i-1)*100+1:i*100)')-hpfilter((TFP2((i-1)*100+1:i*100)'),100000000);                                                                  
dTFP1=dTFP1';dTFP2=dTFP2';                                                                                                                       
dTFP1a=(TFP1((i-1)*100+1:i*100)')-hpfilter((TFP1((i-1)*100+1:i*100)'),1600);                                                                      
dTFP2a=(TFP2((i-1)*100+1:i*100)')-hpfilter((TFP2((i-1)*100+1:i*100)'),1600);                                                                      
dTFP1a=dTFP1a';dTFP2a=dTFP2a';                                                                                                                   
[B1,BINT1,R1,RINT1,STATS1]=regress(dTFP1(2:100)',[ones(1,99);dTFP2(1:99);dTFP1(1:99)]');                                                         
[B2,BINT1,R1,RINT1,STATS1]=regress(dTFP2(2:100)',[ones(1,99);dTFP2(1:99);dTFP1(1:99)]');                                                         
pers1(i)=B1(3);pers2(i)=B2(2);cross1(i)=B1(2);cross2(i)=B2(3);                                                                                   
res(1,:) = dTFP1(2:100) - B1(1)*ones(1,99) - B1(2)*dTFP2(1:99) - B1(3)*dTFP1(1:99);                                                              
res(2,:) = dTFP2(2:100) - B2(1)*ones(1,99) - B2(2)*dTFP2(1:99) - B2(3)*dTFP1(1:99);                                                              
covar(i,1:2,1:2) = cov(res');                                                                                                                    
stdTFP1(i) = std(dTFP1a);                                                                                                                        
stdTFP2(i) = std(dTFP2a);                                                                                                                        
correl(i,1:2,1:2)= corrcoef(dTFP1a,dTFP2a);                                                                                                      
dTFP1=[];dTFP2=[];                                                                                                                               
end                                                                                                                                              
per1=mean(pers1(2:149));                                                                                                                         
per2=mean(pers2(2:149));                                                                                                                         
cr1=mean(cross1(2:149));                                                                                                                         
cr2=mean(cross2(2:149));                                                                                                                         
sd1=mean(stdTFP1(2:149));                                                                                                                        
sd2=mean(stdTFP2(2:149));                                                                                                                        
covv(1:2,1:2)=mean(covar(2:149,1:2,1:2),1);                                                                                                      
correll(1:2,1:2)=mean(correl(2:149,1:2,1:2),1);                                                                                                  
                                                                                                                                                 
%prices                                                                                                                                          
CPI1   = d1(1)/(d1(1)+f1(1))*Pd1+f1(1)/(d1(1)+f1(1))*Pf1;                                                                                                  
CPI2   = d2(1)/(d2(1)+f2(1))*Pd2+f2(1)/(d2(1)+f2(1))*Pf2;                                                                                                  
xTcpi  =  x.*CPI2./CPI1;                                                                                                                         
CPdPf  = Pd1./Pf1;                                                                                                                               
ADVGDP = ( r(dyn_i_a1d(1),:).*v1+...                                                                                                             
          x.*r(dyn_i_a2d(1),:).*v2 )./rGDP1;                                                                                                     
                                                                                                                                                 
%other                                                                                                                                           
LOOP   = (x.*p2d)./p1d;                                                                                                                          
LOOPcpi= (x.*Pd2)./Pd1;                                                                                                                          
LOP2= exp(x.*p2d-p1d);                                                                                                                           
r(dyn_i_LOP(1),:)=exp(r(dyn_i_LOP(1),:));                                                                                                        
PI1    = r(dyn_i_m1d(1),:)./(r(dyn_i_m1d(1),:)+r(dyn_i_m1f(1),:));                                                                               
PI2    = r(dyn_i_m2f(1),:)./(r(dyn_i_m2d(1),:)+r(dyn_i_m2f(1),:));                                                                               
Mup1   = Pd1-v1;                                                                                                                                 
Mup2   = Pf1-x.*v2;                                                                                                                              
                                                                                                                                                 
%trade prices                                                                                                                                    
Px     = x.*p2d./CPI1;                                                                                                                           
Pm     = p1f./CPI1;                                                                                                                              
P      = Pm./Px;                                                                                                                                 
                                                                                                                                                 
%CA                                                                                                                                              
CA     = exp( ( xTcpi.*p2d.*r(dyn_i_d2(1),:)-p1f.*r(dyn_i_f1(1),:))./nGDP1 );                                                                    
                                                                                                                                                 
%domestic absorption less imports                                                                                                                
rDA =rGDP1-p2d(1)*r(dyn_i_d2(1),:);                                                                                                              
nDA =nGDP1-p2d.*r(dyn_i_d2(1),:);                                                                                                                
PDA=nDA./rDA;                                                                                                                                    
                                                                                                                                                 
%Armington elasticity                                                                                                                            
RATdf   = rDA./r(dyn_i_f1(1),:); %r(dyn_i_d1(1),:);                                                                                              
RATpfpd = p1f./PDA;                                                                                                                              
                                                                                                                                                 
neg=0;                                                                                                                                           
                                                                                                                                                 
dyn_i_rGDP1(1) = size(r,1)+1;                                                                                                                    
dyn_i_rGDP2(1) = size(r,1)+2;                                                                                                                    
dyn_i_Px(1)    = size(r,1)+3;                                                                                                                    
dyn_i_Pm(1)    = size(r,1)+4;                                                                                                                    
dyn_i_P(1)     = size(r,1)+5;                                                                                                                    
dyn_i_CA(1)    = size(r,1)+6;                                                                                                                    
dyn_i_TFP1(1)  = size(r,1)+7;                                                                                                                    
dyn_i_TFP2(1)  = size(r,1)+8;                                                                                                                    
dyn_i_xTcpi(1) = size(r,1)+9;                                                                                                                    
dyn_i_LOOP(1)  = size(r,1)+10;                                                                                                                   
dyn_i_Pd1(1)   = size(r,1)+11;                                                                                                                   
dyn_i_Pd2(1)   = size(r,1)+12;                                                                                                                   
dyn_i_Pf2(1)   = size(r,1)+13;                                                                                                                   
dyn_i_Pf1(1)   = size(r,1)+14;                                                                                                                   
dyn_i_LOOPcpi(1)= size(r,1)+15;                                                                                                                  
dyn_i_CPdPf(1) = size(r,1)+16;                                                                                                                   
dyn_i_MUP(1)   = size(r,1)+17;                                                                                                                   
dyn_i_RPC(1)   = size(r,1)+18;                                                                                                                   
dyn_i_PMR(1)   = size(r,1)+19;                                                                                                                   
dyn_i_xPPI(1)  = size(r,1)+20;                                                                                                                   
dyn_i_TME(1)   = size(r,1)+21;                                                                                                                   
dyn_i_CE(1)    = size(r,1)+22;                                                                                                                   
dyn_i_ccs(1)   = size(r,1)+23;                                                                                                                   
dyn_i_p1d(1)   = size(r,1)+24;                                                                                                                   
dyn_i_LOP2(1)   = size(r,1)+25;                                                                                                                  
                                                                                                                                                 
for index  =1:14999                                                                                                                              
inv1(index)=r(dyn_i_k1(1),index+1)-(1-dk)*r(dyn_i_k1(1),index);                                                                                  
inv2(index)=r(dyn_i_k2(1),index+1)-(1-dk)*r(dyn_i_k2(1),index);                                                                                  
                                                                                                                                                 
if inv1(index)<=0 || inv2(index)<=0                                                                                                              
         neg=1;                                                                                                                                  
fprintf('(!) NEGATIVE INVESTMENT IN THE SIMULATION (!) ')                                                                                        
     end                                                                                                                                         
end                                                                                                                                              
                                                                                                                                                 
inv1(15000)=inv1(14999);                                                                                                                         
inv2(15000)=inv2(14999);                                                                                                                         
TS=[r(:,50:15000);rGDP1(50:15000);rGDP2(50:15000);Px(50:15000);Pm(50:15000);...                                                                  
P(50:15000);CA(50:15000);exp(TFP1(50:15000));exp(TFP2(50:15000)); ...                                                                            
xTcpi(50:15000); LOOP(50:15000); ...                                                                                                             
Pd1(50:15000); Pd2(50:15000); Pf2(50:15000); Pf1(50:15000); ...                                                                                  
LOOPcpi(50:15000); exp(CPdPf(50:15000));RMUP(50:15000);RPC(50:15000);...                                                                         
PMR(50:15000);xPPI(50:15000);TME(50:15000);CE(50:15000);ccs(50:15000);p1d(50:15000);LOP2(50:15000)];                                             
                                                                                                                                                 
dTS=log(TS')-hpfilter(log(TS'),1600);                                                                                                             
dx=log(x(50:15000)')-hpfilter(log(x(50:15000)'),1000000);                                                                                         
dxTcpi=log(xTcpi(50:15000)')-hpfilter(log(xTcpi(50:15000)'),1600);                                                                                
dx1=x(50:14999)';                                                                                                                                
dx2=x(51:15000)';                                                                                                                                
                                                                                                                                                 
regA=[RATdf;RATpfpd];                                                                                                                            
regA=log(regA');                                                                                                                                 
dregA=regA-hpfilter(regA,1600);                                                                                                                   
regDA=diff(regA);                                                                                                                                
                                                                                                                                                 
if neg==0                                                                                                                                        
inv1= (Pd1(1)*d1+Pf1(1)*f1).*(inv1./r(dyn_i_G1(1),:));                                                                                           
inv2= (Pd2(1)*d2+Pf2(1)*f2).*(inv2./r(dyn_i_G2(1),:));                                                                                           
	inv=log([inv1(50:15000);inv2(50:15000)]');                                                                                                      
	dinv=inv-hpfilter(inv,1600);                                                                                                                     
end                                                                                                                                              
REG_GC=PI1.*((Pd1-p1d)./Pd1)+(1-PI1).*((Pf1-p1f)./Pf1);                                                                                          
sd=100*std(dTS);                                                                                                                                 
disp('   ')                                                                                                                                      
disp('SIMULATION RESULTS :')                                                                                                                     
disp('========================================')                                                                                                 
disp('PARAMETERS')                                                                                                                               
fprintf('Discount factor            (beta)= %g\n',bet)                                                                                           
fprintf('Labor income in GDP        (alfa)= %g\n',alf)                                                                                           
fprintf('Intertemporal substitution(sigma)= %g\n',sig)                                                                                           
fprintf('Consumption/leisure         (eta)= %g\n',eta)                                                                                           
fprintf('Armington aggreg. elast.  (gamma)= %g\n',gam)                                                                                           
fprintf('Upfront distribution cost   (chi)= %g\n',chi)                                                                                           
fprintf('Home bias parameter  (omega/bias)= %g\n',ome1)                                                                                          
fprintf('Trasportation cost          (tau)= %g\n',tau)                                                                                           
fprintf('Nash bargaining           (theta)= %g\n',tet)                                                                                           
fprintf('Adjustment friction         (phi)= %g\n',2*phi)                                                                                         
disp('   ')                                                                                                                                      
disp('========================================')                                                                                                 
disp('BUSINESS CYCLE VOLATILITY (IN PERCENT)')                                                                                                   
fprintf('s.d.(TFP1 assumed) = %.4f\n',sd(dyn_i_z1(1)))                                                                                           
fprintf('s.d.(TFP2 assumed) = %.4f\n',sd(dyn_i_z2(1)))                                                                                           
fprintf('s.d.(OUTPUT)       = %.4f\n',sd(dyn_i_rGDP1(1)))                                                                                        
fprintf('s.d.(CONSUMPTION)  = %.4f\n',sd(dyn_i_c1(1)))                                                                                           
fprintf('s.d.(CA)           = %.4f\n',sd(dyn_i_CA(1)))                                                                                           
fprintf('s.d.(TOT)          = %.4f\n',sd(dyn_i_P(1)))                                                                                            
fprintf('s.d.(RER_CPI)      = %.4f\n',sd(dyn_i_xTcpi(1)))                                                                                        
fprintf('s.d.(Px)           = %.4f\n',sd(dyn_i_Px(1)))                                                                                           
fprintf('s.d.(Pm)           = %.4f\n',sd(dyn_i_Pm(1)))                                                                                           
fprintf('s.d.(v)            = %.4f\n',sd(dyn_i_vd(1)))                                                                                           
fprintf('s.d.(xpd/pd)       = %.4f\n',sd(dyn_i_LOOP(1)))                                                                                         
fprintf('s.d.(xPd/Pd)       = %.4f\n',sd(dyn_i_LOOPcpi(1)))                                                                                      
fprintf('s.d.(Pd/Pf)        = %.4f\n',sd(dyn_i_CPdPf(1)))                                                                                        
fprintf('s.d.(xpd*-v)/(pd-v)= %.4f\n',sd(dyn_i_MUP(1)))                                                                                          
fprintf('s.d.Thick Market   = %.4f\n',sd(dyn_i_TME(1)))                                                                                          
fprintf('s.d.Congestion     = %.4f\n',sd(dyn_i_CE(1)))                                                                                           
    sdinv=100*std(dinv);                                                                                                                         
disp('=======================================')                                                                                                  
warning off MATLAB:divideByZero                                                                                                                  
                                                                                                                                                 
cc= corrcoef(dTS);                                                                                                                               
                                                                                                                                                 
disp('INTERNATIONAL CORRELATIONS')                                                                                                               
fprintf('corr(TFP assumed) = %.2f\n',cc(dyn_i_z1(1),dyn_i_z2(1)))                                                                                
fprintf('corr(OUTPUT)      = %.2f\n',cc(dyn_i_rGDP1(1),dyn_i_rGDP2(1)))                                                                          
fprintf('corr(CONSUMPTION) = %.2f\n',cc(dyn_i_c1(1),dyn_i_c2(1)))                                                                                
if neg==0                                                                                                                                        
ccinv= corrcoef(dinv);                                                                                                                           
end                                                                                                                                              
                                                                                                                                                 
fprintf('corr(Px,Pm)       = %.2f\n',cc(dyn_i_Px(1),dyn_i_Pm(1)))                                                                                
fprintf('corr(Px,RER)      = %.2f\n',cc(dyn_i_Px(1),dyn_i_xTcpi(1)))                                                                             
fprintf('corr(Pm,RER)      = %.2f\n',cc(dyn_i_Pm(1),dyn_i_xTcpi(1)))                                                                             
fprintf('corr(TOT,RER)      = %.2f\n',cc(dyn_i_P(1),dyn_i_xTcpi(1)))                                                                             
correlPxRer1=corrcoef(dTS(2:14000,dyn_i_Px(1)), dxTcpi(1:13999));                                                                                
fprintf('corr(Px,RER(-1))  = %.2f\n',correlPxRer1(2,1))                                                                                          
RERauto=corrcoef([dx2 dx1]);                                                                                                                     
fprintf('corr(RER,RER(-1)) = %.3f\n',RERauto(2,1))                                                                                               
                                                                                                                                                 
disp('=========================================')                                                                                                
                                                                                                                                                 
disp('BUSINESS CYCLE CORRELATIONS')                                                                                                              
                                                                                                                                                 
fprintf('corr(OUTPUT,CONS.)= %.2f\n',cc(dyn_i_rGDP1(1),dyn_i_c1(1)))                                                                             
if neg==0                                                                                                                                        
ccyi=corrcoef(dinv(:,1),dTS(:,dyn_i_rGDP1(1)));                                                                                                  
end                                                                                                                                              
                                                                                                                                                 
fprintf('corr(OUTPUT,CA)   = %.2f\n',cc(dyn_i_rGDP1(1),dyn_i_CA(1)))                                                                             
fprintf('corr(TOT,CA)      = %.2f\n',cc(dyn_i_P(1),    dyn_i_CA(1)))                                                                             
fprintf('corr(TOT,RER)     = %.2f\n',cc(dyn_i_P(1),    dyn_i_xTcpi(1)))                                                                          
                                                                                                                                                 
disp('=========================================')                                                                                                
disp('Data has been logged & HP filtered (1600) except CA, ')                                                                                    
disp('CA has been divided by nom. GDP and then HP filtered.  ')                                                                                  
disp('   ')                                                                                                                                      
disp('COMPILED STATISTICS')                                                                                                                      
coefreg0=regress(dregA(100:14900,1),[ones(14801,1) dregA(100:14900,2)]);                                                                         
coefreg1=regress(dTS(100:14000,dyn_i_Pm(1)),[ones(13901,1) dTS(100:14000,dyn_i_xTcpi(1))]);                                                      
coefreg2=regress(regA(100:14900,1),[ones(14801,1) regA(100:14900,2)]);                                                                           
corPxX=corrcoef(dTS(100:14000,dyn_i_Px(1)),dTS(100-1:14000-1,dyn_i_xTcpi(1)));                                                                             
coefreg3=regress(dTS(100:14000,dyn_i_Px(1)),[ones(13901,1) dTS(100:14000,dyn_i_xTcpi(1))]);                                                      
[B1,BINT1,R1,RINT1,STATS1]=regress(exp(TFP1(51:14001))',[ones(1,13951);exp(TFP1(50:14000))]');                                                   
[BGC,BINTGC,RGC,RINTGC,STATSGC]=regress(diff(log(REG_GC))',[ones(1,14999);diff(log(x))]');                                                       
sm   = dyn_ss(dyn_i_vd(1))*(r(dyn_i_a1d(1),1)+r(dyn_i_a2d(1),1))/nGDP1(1);                                                                       
miuP = (p1d(1)-dyn_ss(dyn_i_vd(1)))/dyn_ss(dyn_i_vd(1));                                                                                         
miuD = (chi)*r(dyn_i_vd(1),1)/(PI1(1)*p1d(1)+(1-PI1(1))*p1f(1));                                                                                 
fprintf('S-R Regression (HP1600)                   = %.2f\n',coefreg0(2))                                                                        
fprintf('S-R Regression (levels)                   = %.2f\n',coefreg2(2))                                                                        
fprintf('1. Real SR pass-through (import)          = %.2f%%\n',(100*coefreg1(2)))                                                                
fprintf('1a.1 - Real SR pass-through (export)      = %.2f%%\n',(100*(1-coefreg3(2))))                                                            
fprintf('2. Imports in GDP                         = %.2f%%\n', (100*(1-Omg)))                                                                   
fprintf('3. Advertising in GDP                     = %.2f%%\n', 100*sm)                                                                          
fprintf('4. Producer Markups                       = %.2f%%\n', 100*miuP)                                                                        
fprintf('5. Distribution margin                    = %.2f%%\n', 100*miuD)                                                                        
fprintf('6. sd(f/d)/sd(Pd/pf) (Volatility Ratio)   = %.1f%%\n', 100*std(dregA(50:15000,1))/std(dregA(50:15000,2)))                               
fprintf('7. sd(f/d)/sd(RER)                        = %.2f%%\n', (10000*std(dregA(50:15000,1))/sd(dyn_i_xTcpi(1))))                               
fprintf('8. sd(px)/sd(RER)                         = %.2f%%\n', (100*sd(dyn_i_Px(1))/sd(dyn_i_xTcpi(1))))                                        
fprintf('9. sd(pm)/sd(RER)                         = %.2f%%\n', (100*sd(dyn_i_Pm(1))/sd(dyn_i_xTcpi(1))))                                        
fprintf('10. sd(pd)/sd(RER)                        = %.2f%%\n', (100*sd(dyn_i_p1d(1))/sd(dyn_i_xTcpi(1))))                                       
fprintf('11. sd(TOT)/sd(RER)                       = %.2f%%\n', (100*sd(dyn_i_P(1))/sd(dyn_i_xTcpi(1))))                                         
fprintf('11. sd(px/pd)/sd(RER)                     = %.2f%%\n', (100*sd(dyn_i_LOOP(1))/sd(dyn_i_xTcpi(1))))                                      
fprintf('12. Contribution of deviation from LOP for marketing and search costs (LOPD) = %.2f%%\n', 100*sd(dyn_i_LOP(1))/sd(dyn_i_LOP2(1)))       
fprintf('13. Corr(c/c*, RER)                       = %.2f\n', cc(dyn_i_ccs(1),dyn_i_xTcpi(1)))                                                   
fprintf('14. sd(consumption)/sd(GDP)               = %.2f%%\n', (100*sd(dyn_i_c1(1))/sd(dyn_i_rGDP1(1))))                                        
fprintf('15. sd(Net exports)/sd(GDP)               = %.2f%%\n', (100*sd(dyn_i_CA(1))/sd(dyn_i_rGDP1(1))))                                        
disp('PROPERTIES OF THE ACTUAL MEASURED TFP PROCESS')                                                                                            
fprintf('a. ACTUAL rho11        = %.2f\n', per1)                                                                                                 
fprintf('b. ACTUAL rho22        = %.2f\n', per2)                                                                                                 
fprintf('c. ACTUAL rho12        = %.2f\n', cr1)                                                                                                  
fprintf('d. ACTUAL rho21        = %.2f\n', cr2)                                                                                                  
fprintf('e. std(TFP)            = %.5f\n', sd1)                                                                                                  
fprintf('f. std(TFP*)           = %.5f\n', sd2)                                                                                                  
fprintf('g. corr(TFP,TFP*)      = %.5f\n', correll(1,2)) 
disp('========================================= Execution complete')
                                                                                                                                                 
                                 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                                                                                                                              
                                                                                                                                                 
T=40;                                                                                                                                            
figure(1);                                                                                                                                       
subplot(2,2,1)                                                                                                                                   
plot([0:T],100*r(dyn_i_z1(1),1:T+1)/r(dyn_i_z1(1),1)-100,'--k',[0:T],100*r(dyn_i_z2(1),1:T+1)/r(dyn_i_z2(1),1)-100,'b','LineWidth',2)            
ylabel('Percent deviation','FontSize',9)                                                                                                         
xlabel('Quarters after shock','FontSize',9)                                                                                                      
legend('z1','z2')                                                                                                                                
grid on                                                                                                                                          
                                                                                                                                                 
subplot(2,2,2)                                                                                                                                   
plot([0:T],f1(1:T+1)./(d1(1:T+1)+f1(1:T+1)),'--k',[0:T],d2(1:T+1)./(d2(1:T+1)+f2(1:T+1)),'b','LineWidth',2)                                      
ylabel('Percent deviation','FontSize',9)                                                                                                         
xlabel('Quarters after shock','FontSize',9)                                                                                                      
legend('f1/(f1+d1)', 'd2/(f2+d2)')                                                                                                               
grid on                                                                                                                                          
                                                                                                                                                 
subplot(2,2,3)                                                                                                                                   
plot([0:T],100*x(1:T+1)/x(1)-100,'--k',[0:T],100*Px(1:T+1)/Px(1)-100,...                                                                         
[0:T],100*Pm(1:T+1)/Pm(1)-100,[0:T],100*p1d(1:T+1)/p1d(1)-100,'LineWidth',2)                                                                     
ylabel('Percent deviation','FontSize',9)                                                                                                         
xlabel('Quarters after shock','FontSize',9)                                                                                                      
legend('x', 'p_x', 'p_m', 'p_d' )                                                                                                                
grid on                                                                                                                                          
                                                                                                                                                 
subplot(2,2,4)                                                                                                                                   
plot([0:T],100*Pd1(1:T+1)/Pd1(1)-100,'--k',[0:T],100*x(1:T+1).*Pd2(1:T+1)/(x(1)*Pd2(1))-100,'b','LineWidth',2)                                   
ylabel('Percent deviation','FontSize',9)                                                                                                         
xlabel('Quarters after shock','FontSize',9)                                                                                                      
legend('Pd1', 'xPd2')                                                                                                                            
grid on                                                                                                                                          
                                                                                                               
