%Generates Tables 1-2 from the paper, and all tables from the technical
%appendix. Runs first RER_NEW.m file. 

%Runs only on MATLAB version 7 or later (needs to be able to read from Excel
%file, version 6 does not read cell refs.)

clear
close all
clc

RER_NEW %load data

gam=.44; sh =0.5; HP=1600;

REER04 = eCPIs./CPI; %constructed extended REER (based on 12 countries)
REER=100./REERoecd; %use REER from OECD

%HP filter RER series
dNEER04    = log(NEERIFS04)  -hptrend(log(NEERIFS04),1600);
dREER04    = log(REERoecd04) -hptrend(log(REERoecd04),1600);
dREER04_our= log(REER04) -hptrend(log(REER04),1600);
dREER      = log(REER)       -hptrend(log(REER),1600);
dREERPPI04 = log(REER_PPI04) -hptrend(log(REER_PPI04),1600);
dREERCPIT04= log(rerTcpi)    -hptrend(log(rerTcpi),1600);

Px04       = EPI04./CPI;
Pm04       = IPI04./CPI;
PxPPI04    = EPI04./PPI04;
PmPPI04    = IPI04./PPI04;
TOT04      = IPI04./EPI04; %extended dates

dPx04      = log(Px04)   -hptrend(log(Px04),HP);
dPm04      = log(Pm04)   -hptrend(log(Pm04),HP);

dPxPPI04   = log(PxPPI04)-hptrend(log(PxPPI04),HP);
dPmPPI04   = log(PmPPI04)-hptrend(log(PmPPI04),HP);
dTOT04     = log(TOT04)  -hptrend(log(TOT04),HP);

%Short list for the Appendix
dEPI04 = log(EPI04) -hptrend(log(EPI04),HP);
dIPI04 = log(IPI04) -hptrend(log(IPI04),HP);

 
%Robustness to non-tradable goods
%As described in Technical Appendix to the paper

EPIs= EPI(:,1:counts);
IPIs= IPI(:,1:counts);

Pxs = EPIs./CPI_AI;
Pms = IPIs./CPI_AI;

PxNs= EPIs./CPI_N;
PmNs= IPIs./CPI_N;

%Construct stantiary time-series centered around 1 using HP filter with
%HP smoothing parameter
dEPIs=log(EPIs)-hptrend(log(EPIs),HP);
dIPIs=log(IPIs)-hptrend(log(IPIs),HP);
dPxs=log(Pxs)-hptrend(log(Pxs),HP);
dPms=log(Pms)-hptrend(log(Pms),HP);
dPxNs=log(PxNs)-hptrend(log(PxNs),HP);
dPmNs=log(PmNs)-hptrend(log(PmNs),HP);
dPxs=dPxs+ones(80,9);
dPms=dPms+ones(80,9);
dPxNs=dPxNs+ones(80,9);
dPmNs=dPmNs+ones(80,9);

%Construct tradable series
rho  =(1-gam)/gam;
PxTTs=( (dPxs.^rho-(1-sh)*dPxNs.^rho)/sh ).^(1/rho);
PmTTs=( (dPms.^rho-(1-sh)*dPmNs.^rho)/sh ).^(1/rho);

PxTs    = Pxs.*(EPIs./CPI_N).^sh;
PmTs    = Pms.*(IPIs./CPI_N).^sh;

dPxs    = log(Pxs)-hptrend(log(Pxs),HP);
dPms    = log(Pms)-hptrend(log(Pms),HP);

dPxTs   = log(PxTs)-hptrend(log(PxTs),HP);
dPmTs   = log(PmTs)-hptrend(log(PmTs),HP);

dPxTTs  = log(PxTTs)-hptrend(log(PxTTs),HP);
dPmTTs  = log(PmTTs)-hptrend(log(PmTTs),HP);

for i=1:counts %short list based constructs with tradable CPI used
    CCPxTTPmTTs(:,:,i) = corrcoef(dPxTTs(:,i),dPmTTs(:,i));
    CCPxTPmTs(:,:,i)   = corrcoef(dPxTs(:,i),dPmTs(:,i));
    CCPxPms(:,:,i)     = corrcoef(dPxs(:,i),dPms(:,i));
    
    CCREERPxTTs(:,:,i) = corrcoef(dPxTTs(:,i),dREER(:,i));
    CCREERPmTTs(:,:,i)   = corrcoef(dPmTTs(:,i),dREER(:,i));
    CCREERPxTs(:,:,i)     = corrcoef(dPxTs(:,i),dREER(:,i));
    CCREERPmTs(:,:,i)     = corrcoef(dPmTs(:,i),dREER(:,i));

end

for i=1:countl %long list based constructs
    CCPxPm04(:,:,i) = corrcoef(dPx04(:,i),dPm04(:,i));
    CCEPIIPI04(:,:,i) = corrcoef(dEPI04(:,i),dIPI04(:,i));
    CCPxPmPPI04(:,:,i) = corrcoef(dPxPPI04(:,i),dPmPPI04(:,i));
    CCREERPx04(:,:,i) = corrcoef(dPx04(:,i),dREER04(:,i));
    CCREERPm04(:,:,i) = corrcoef(dREER04(:,i),dPm04(:,i));
    CCREERPxPPI04(:,:,i) = corrcoef(dPxPPI04(:,i),dREERPPI04(:,i));
    CCREERPmPPI04(:,:,i) = corrcoef(dREERPPI04(:,i),dPmPPI04(:,i));
    CCNEEREPI04(:,:,i) = corrcoef(dEPI04(:,i),dNEER04(:,i));
    CCNEERIPI04(:,:,i) = corrcoef(dNEER04(:,i),dIPI04(:,i));
    SDPx04(i)       = std(dPx04(:,i))*100;
    SDPm04(i)       = std(dPm04(:,i))*100;
    SDREER04(i)     = std(dREER04(:,i))*100;
    SDNEER04(i)     = std(dNEER04(:,i))*100;
    SDREERPPI04(i)  = std(dREERPPI04(:,i))*100;
    SDREER04_our(i) = std(dREER04_our(:,i))*100;
    SDTOT04(i)      = std(dTOT04(:,i))*100;
end

ssx04  =SDPx04./SDREER04*100; %relative volatility of real export price to rer
ssm04  =SDPm04./SDREER04*100; %relative volatility of real import price to rer
sstot04=SDTOT04./SDREER04*100; %relative volatility of terms of trade to rer

%==========================================================================
%Figure 1. Px, Pm, Cross-Country Comparison
figure('Name','Px, Pm Cross-Country Comparison (HP 1600)')
whitebg('white')
set(gcf,'Color',[1,1,1])
for i=1:countl
subplot(4,3,i)
%plot([1:98],dPx04(1:98,i)*100,'-b',[1:98],dPm04(1:98,i)*100,'--r','LineWidth',1.3)
plot([1:98],dPx04(1:98,i)*100,'-b',[1:98],dPm04(1:98,i)*100,'--r',[1:98],dREER04(1:98,i)*100,':m','LineWidth',1.3)
set(gca,'Fontsize',6);
title(char(country_ext(i,:)), 'FontSize',9)
ylabel('Percent','FontSize',6)
xlabel('Quarter','FontSize',6)
if i==1
   legend('p_x','p_m','x')
   %   legend('p_x','p_m')
end
grid on
axis([1  100  -20 20])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%TABLE 1 in the technical appendix. 
%
file ={'Table1a.txt'};
title={'Correlation of Export and Import Prices in the CES Case.'};
label={'Table1a'};

chead=[0 1 2 2 2 2 2
       1 1 1 1 1 1 1];

hrow ={'Correlation', ...
       'Country',...
       '\footnotesize $p_x^{ces},p_m^{ces}$', ...
       '\footnotesize $p_x^{ces},x$', ...
       '\footnotesize $p_m^{ces},x$', ...
       '\footnotesize $p_x^{T},p_m^{T}$', ...
       '\footnotesize $p_x^{T},x$', ...
       '\footnotesize $p_m^{T},x$', ...
       }

data=ones(counts,6);

for i=1:counts
    data(i,:)=[CCPxTTPmTTs(2,1,i) CCREERPxTTs(2,1,i) CCREERPmTTs(2,1,i) ...
               CCPxTPmTs(2,1,i)   CCREERPxTs(2,1,i)  CCREERPmTs(2,1,i)];
end

%for i=counts+1:countl
%data(i,:)=[CCREERPx04(2,1,i) CCREERPm04(2,1,i) 0.0 0.0 CCREERPxPPI04(2,1,i) CCREERPmPPI04(2,1,i) CCNEEREPI04(2,1,i) CCNEERIPI04(2,1,i)];
%end
%fcol=country_ext; 
hline=[]; 
fcol=country; 
csin=[1.5; 0.65;.55;.55;.45;.45;.45]; 
dec =[         2;  2;  2;  2;  2;  2];
opt =[1 0];
fnote={'Notes: $x$ denotes trade-weighted real exchange rate (from IMF-IFS database). All statistics based on logged \& Hodrick-Prescott filtered (with $\lambda=1600$) quarterly time series for the period 1980:1-2004:2 except for CPI of tradables series which ends in 2000. Sources listed in the Data Appendix.'};
small=[]; 
TabTeX(file,title,label,chead,hrow,fcol,hline,csin,dec,data,fnote,opt);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%TABLE 1 in the technical appendix. 
%
file ={'Table2a.txt'};
title={'Correlation of Nominal and PPI deflated Export and Import Prices'};
label={'Table2a'};

chead=[0 1 2 2 2 2 2
       1 1 1 1 1 1 1];

hrow ={'Correlation', ...
       'Country',...
       '\footnotesize $EPI,IPI$', ...
       '\footnotesize $EPI,e$', ...
       '\footnotesize $IPI,e$', ...
       '\footnotesize $p_x^{ppi},p_m^{ppi}$', ...
       '\footnotesize $p_x^{ppi},x$', ...
       '\footnotesize $p_m^{ppi},x$', ...
       }

data=ones(counts,6);

for i=1:countl
    data(i,:)=[CCEPIIPI04(2,1,i) CCNEEREPI04(2,1,i) CCNEERIPI04(2,1,i) ...
               CCPxPmPPI04(2,1,i)   CCREERPx04(2,1,i)  CCREERPm04(2,1,i)];
end

fcol=country_ext; 
hline=[]; 
csin=[1.5; 0.65;.55;.55;.45;.45;.45]; 
dec =[         2;  2;  2;  2;  2;  2];
opt =[1 0];
fnote={'Notes: $EPI$ denotes nominal export price index, $IPI$ denotes nominal import price index, $e$ denotes trade-weighted nominal exchange rate (from IMF-IFS database), $x$ denotes analogous real exchange rate. All statistics based on logged \& Hodrick-Prescott filtered (with $\lambda=1600$) quarterly time series for the period 1980:1-2004:2 except for CPI of tradables series which ends in 2000. Sources listed in the Data Appendix.'};
small=[]; 
TabTeX(file,title,label,chead,hrow,fcol,hline,csin,dec,data,fnote,opt);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%TABLE 1 in the paper.
%
file ={'Table1.txt'};
title={'Correlation of Export and Import Prices'};
label={'Table1'};

chead=[0 1 2 2 2 2 2
       1 1 1 1 1 1 1];

hrow ={'Correlation', ...
       'Country',...
       '\footnotesize $p_x,p_m$', ...
       '\footnotesize $p_x,x$', ...
       '\footnotesize $p_m,x$', ...
       '\footnotesize $p_x^{T},p_m^{T}$', ...
       '\footnotesize $p_x^{T},x$', ...
       '\footnotesize $p_m^{T},x$', ...
       }
data=ones(counts,6);

for i=1:counts
    data(i,:)=[CCPxPm04(2,1,i) CCREERPx04(2,1,i) CCREERPm04(2,1,i) CCPxTPmTs(2,1,i) CCREERPxTs(2,1,i) CCREERPmTs(2,1,i)];
end
for i=counts+1:countl
    data(i,:)=[CCPxPm04(2,1,i) CCREERPx04(2,1,i) CCREERPm04(2,1,i) 0.0 0.0 0.0];
end
fcol=country_ext; hline=[8;9]; 
csin=[1.6; 0.45;.45;.45;.45;.45;.45]; 
dec =[         2;  2;  2;  2;  2;  2];
opt=[1 0];
fnote={'Notes: All statistics are based on logged \& H-P-filtered quarterly time series.  Except for T-time series which ends in 2000, the time-series range from 1980:1 to 2004:2. Sources are listed in the appendix at the end. '};
small=[]; 
TabTeX(file,title,label,chead,hrow,fcol,hline,csin,dec,data,fnote,opt);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%TABLE 2 in the paper. 
%
file ={'Table2.txt'};
title={'Volatility of Terms of Trade Relative to Real Exchange Rate'};
label={'Table2'};

chead=[0 1 2 2;
       0 1 2 2;
       1 1 1 1];
   hrow ={'\small Volatility of $p$ relative to $x$','\small Price index used to construct$^{a}$ $x$','Country',...
       '\footnotesize CPI all-items','\footnotesize WPI or PPI','\footnotesize None (nominal)'}

data=ones(countl,3);
small=[]; 
for i=1:countl
    data(i,:)=[SDTOT04(1,i)/SDREER04_our(1,i) SDTOT04(1,i)/SDREERPPI04(1,i) SDTOT04(1,i)/SDNEER04(1,i)];
end

fcol = country_ext; hline=[]; 
csin=[1.6;0.95;0.95;0.95];
dec =[      2;  2;  2];
opt=[1 0];
fnote= {'We have constructed trade-weghted exchange rates using weights and bilateral exchange rate for the set of 11 trading partners for each country. The trading partners include the countries listed in this table. Statistics are computed from logged H-P-filtered quarterly time-series for the period 1980:1-2000.01. Sources are listed in the appendix at the end.'};

TabTeX(file,title,label,chead,hrow,fcol,hline,csin,dec,data,fnote,opt);

PrevTeX({'Table1.txt','Table2.txt','Table1a.txt','Table2a.txt'});